@@ -37,7 +37,7 @@ main ()
     bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
-    if (g_file_test ("/var/run/avahi-daemon/disabled-for-unicast-local", G_FILE_TEST_EXISTS)) {
+    if (g_file_test ("/run/avahi-daemon/disabled-for-unicast-local", G_FILE_TEST_EXISTS)) {
         show_notification();
         return 0;
     } else
