@@ -14,7 +14,7 @@ def get_message(*args, **kwds):
 
 
 class TestMotd(unittest.TestCase):
-    """ ensure that the tree is pep8 clean """
+    """ Validate /etc/motd text """
 
     def test_esm_disabled_upto_date_esm_avail(self):
         self.assertEqual(
